pub struct InstanceSnapshot {
pub instance_id: InstanceId,
pub graphic_id: String,
pub data: Option<Value>,
pub current_step: Option<f64>,
}Expand description
Instance state snapshot sent by a renderer during reconnect (Hello message). Contains the minimal information needed to resync Core’s view of what instances are loaded on the renderer.
Fields
instance_id: InstanceIdgraphic_id: Stringdata: Option<Value>current_step: Option<f64>Trait Implementations
Sourceimpl Clone for InstanceSnapshot
impl Clone for InstanceSnapshot
Sourceimpl Debug for InstanceSnapshot
impl Debug for InstanceSnapshot
Sourceimpl<'de> Deserialize<'de> for InstanceSnapshot
impl<'de> Deserialize<'de> for InstanceSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more